package org.cesg.utilidades;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Convertir.java<br/>
 * Contiene métodos estatic para poder convertir cadenas ( String ) a números
 * 
 * @author cesg
 * 
 */
public final class Convertir {
    private static final Logger logger = LoggerFactory
            .getLogger(Convertir.class);

    /**
     * Convierte un {@link java.lang.String String} a un número
     * {@link java.lang.Integer Integer} utilizando el método<br/>
     * Integer.parseInt();<br/>
     * si no se logra convertir la cadena a un número retornará <b>null<b/>
     * 
     * @param value
     *            cadena que se quiere convertir a Integer.
     * @return valor obtenido de la conversión, null si no logro convertir.
     */
    public static final Integer aInteger ( String value) {
        Integer valor = null;
        value = value.trim();
        try {
            valor = Integer.parseInt(value);
        }
        catch ( final NumberFormatException e ) {
            logger.error("# Error al convertir, {}", e.getMessage());
        }
        return valor;
    }

    /**
     * Convierte un {@link java.lang.String String} a un número int utilizando
     * el método<br/>
     * Integer.parseInt();<br/>
     * si no se logra convertir la cadena a un número retornará el valor por
     * defecto asignado.
     * 
     * @param valor
     *            cadena que se quiere convertir a int.
     * @param valorPorDefecto
     *            valor a asignar en caso de lograr convertir la cadena.
     * @return valor obtenido de la conversión, valorPorDefecto si no logro
     *         convertir.
     */
    public static final int aInt ( String valor , int valorPorDefecto) {
        valor = valor.trim();
        try {
            valorPorDefecto = Integer.parseInt(valor);
        }
        catch ( final NumberFormatException e ) {
            logger.error("# Error al convertir, {}", e.getMessage());
        }
        return valorPorDefecto;
    }

    /**
     * Convierte un {@link java.lang.String String} a un número
     * {@link java.lang.Long Long} utilizando el método<br/>
     * Long.parseLong();<br/>
     * si no se logra convertir la cadena a un número retornará <b>null<b/>
     * 
     * @param value
     *            cadena que se quiere convertir a Long.
     * @return valor obtenido de la conversión, null si no se logro convertir.
     */
    public static final Long aLong ( String valor) {
        Long valorLong = null;
        valor = valor.trim();
        try {
            valorLong = Long.parseLong(valor);
        }
        catch ( final NumberFormatException e ) {
            logger.error("# Error al convertir, {}", e.getMessage());
        }

        return valorLong;
    }

    /**
     * Convierte un {@link java.lang.String String} a un número
     * {@link java.lang.Float Float} utilizando el método<br/>
     * Float.parseFloat();<br/>
     * si no se logra convertir la cadena a un número retornará <b>null<b/>
     * 
     * @param value
     *            cadena que se quiere convertir a Float.
     * @return valor obtenido de la conversión, null si no se logro convertir.
     */
    public static final Float aFloat ( String valor) {
        Float valorFloat = null;
        valor = valor.trim();
        try {
            valorFloat = Float.parseFloat(valor);
        }
        catch ( final NumberFormatException e ) {
            logger.error("# Error al convertir, {}", e.getMessage());
        }
        return valorFloat;
    }
}
