package org.cesg.utilidades.mensajes;

import java.awt.Component;

import javax.swing.JOptionPane;

import org.cesg.utilidades.Convertir;
import org.cesg.utilidades.Verifica;

/**
 * JOptionPaneUtils.java <br/>
 * Implementa<br/>
 * {@link org.cesg.utilidades.mensajes.MuestraMensajes MuestraMensajes},
 * {@link org.cesg.utilidades.mensajes.PreguntaDato ObtenerDato}<br/>
 * utilizando {@link javax.swing.JOptionPane JOptionPane} para mostrar
 * graficacamente el mensaje.
 * 
 * @see org.cesg.utilidades.mensajes.MuestraMensajes
 * @author cesg
 * @version 18.06.2012
 */
public final class JOptionPaneUtils implements MuestraMensajes , PreguntaDato {

    private static final String TITULO_INFORMACION = "[ Información ]";
    private static final String TITULO_ERROR = "[ Error ]";
    private static final String TITULO_ATENCION = "[ Atención ]";
    private static final String TITULO_PREGUNTA = "[ Pregunta ]";

    /**
     * Instancia de {@link JOptionPaneUtils}
     */
    public JOptionPaneUtils () {
    }

    public void mensajeAtencion ( Component component , String mensaje) {
        JOptionPane.showMessageDialog(component, mensaje, TITULO_ATENCION,
                JOptionPane.WARNING_MESSAGE);
    }

    public void mensajeAtencion ( String mensaje) {
        JOptionPane.showMessageDialog(null, mensaje, TITULO_ATENCION,
                JOptionPane.WARNING_MESSAGE);

    }

    public void mensajeAtencion ( Object mensaje) {
        JOptionPane.showMessageDialog(null, mensaje, TITULO_ATENCION,
                JOptionPane.WARNING_MESSAGE);
    }

    public void mensajeError ( Component component , String mensaje) {
        JOptionPane.showMessageDialog(component, mensaje, TITULO_ERROR,
                JOptionPane.ERROR_MESSAGE);
    }

    public void mensajeError ( String mensaje) {
        JOptionPane.showMessageDialog(null, mensaje, TITULO_ERROR,
                JOptionPane.ERROR_MESSAGE);

    }

    public void mensajeError ( Object mensaje) {
        JOptionPane.showMessageDialog(null, mensaje, TITULO_ERROR,
                JOptionPane.ERROR_MESSAGE);
    }

    public void mensajeInformacion ( Component component , String mensaje) {
        JOptionPane.showMessageDialog(component, mensaje, TITULO_INFORMACION,
                JOptionPane.INFORMATION_MESSAGE);
    }

    public void mensajeInformacion ( String mensaje) {
        JOptionPane.showMessageDialog(null, mensaje, TITULO_INFORMACION,
                JOptionPane.INFORMATION_MESSAGE);
    }

    public void mensajeInformacion ( Object mensaje) {
        JOptionPane.showMessageDialog(null, mensaje, TITULO_INFORMACION,
                JOptionPane.INFORMATION_MESSAGE);

    }


    public String datoString ( String mensaje) {
        final String valor = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA,
                JOptionPane.QUESTION_MESSAGE);
        return valor;
    }


    public String datoString ( Object mensaje) {
        final String valor = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);
        return valor;
    }


    public Integer datoInteger ( String mensaje) {
        final String valorStr = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);

        Integer valorInt = Convertir.aInteger(valorStr);
        if ( Verifica.isNull(valorInt) )
            mensajeError("Debe ingresar un valor entero correcto!.");
        return valorInt;
    }

    public Integer datoInteger ( Object mensaje) {
        final String valorStr = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);
        Integer valorInt = Convertir.aInteger(valorStr);
        if ( Verifica.isNull(valorInt) )
            mensajeError("Debe ingresar un valor entero correcto!.");
        return valorInt;
    }

    public Integer datoInteger ( final String mensaje ,
            final String mensajeError) {
        final String valorStr = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);
        Integer valorInt = Convertir.aInteger(valorStr);
        if ( Verifica.isNull(valorInt) )
            mensajeError(mensajeError);
        return valorInt;
    }

    public Float datoFloat ( String mensaje) {
        final String valorStr = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);
        Float valorFloat = Convertir.aFloat(valorStr);
        if ( Verifica.isNull(valorFloat) )
            mensajeError("Debe ingresar un valor float correcto!.");
        return valorFloat;
    }

    public Float datoFloat ( Object mensaje) {
        final String valorStr = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);
        Float valorFloat = Convertir.aFloat(valorStr);
        if ( Verifica.isNull(valorFloat) )
            mensajeError("Debe ingresar un valor float correcto!.");
        return valorFloat;
    }

    public Float datoFloat ( String mensaje , String mensajeError) {
        final String valorStr = JOptionPane.showInputDialog(null, mensaje,
                TITULO_PREGUNTA, JOptionPane.QUESTION_MESSAGE);
        Float valorFloat = Convertir.aFloat(valorStr);
        if ( Verifica.isNull(valorFloat) )
            mensajeError(mensajeError);
        return valorFloat;
    }

}
